@@ -467,11 +467,7 @@ namespace Konversation
 
             //connect(m_dccSocket, SIGNAL(hostFound()), this, SLOT(lookupFinished()));
             connect(m_dccSocket, &QTcpSocket::connected, this, &Chat::connectionEstablished);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
             connect(m_dccSocket, &QTcpSocket::errorOccurred, this, &Chat::connectionFailed);
-#else
-            connect(m_dccSocket, QOverload<QAbstractSocket::SocketError>::of(&QTcpSocket::error), this, &Chat::connectionFailed);
-#endif
             connect(m_dccSocket, &QTcpSocket::readyRead, this, &Chat::readData);
             connect(m_dccSocket, &QTcpSocket::disconnected, this, &Chat::socketClosed);
 
@@ -513,11 +509,7 @@ namespace Konversation
                 line = codec->toUnicode(buffer);
                 delete[] buffer;
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-                const QStringList &lines = line.split(QLatin1Char('\n'), QString::SkipEmptyParts);
-#else
                 const QStringList &lines = line.split(QLatin1Char('\n'), Qt::SkipEmptyParts);
-#endif
                 for (const QString &lin : lines) {
                     Q_EMIT receivedRawLine(lin);
                 }
@@ -538,11 +530,7 @@ namespace Konversation
         {
             if (m_dccSocket && m_textStream.device())
             {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
                 m_textStream << text << Qt::endl;
-#else
-                m_textStream << text << endl;
-#endif
             }
         }
 
@@ -565,11 +553,7 @@ namespace Konversation
 
             connect(m_dccSocket, &QTcpSocket::readyRead, this, &Chat::readData);
             connect(m_dccSocket, &QTcpSocket::disconnected, this, &Chat::socketClosed);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
             connect(m_dccSocket, &QTcpSocket::errorOccurred, this, &Chat::connectionFailed);
-#else
-            connect(m_dccSocket, QOverload<QAbstractSocket::SocketError>::of(&QTcpSocket::error), this, &Chat::connectionFailed);
-#endif
             // the listen socket isn't needed anymore
             disconnect(m_dccServer, nullptr, nullptr, nullptr);
             m_dccServer->close();
