@@ -1431,6 +1431,11 @@ QString IRCView::ircTextToHtml(const QString& text, bool parseURL, const QString
                 pos += offset -1;
                 linkOffset += offset -1;
                 break;
+            case '\x11': //monospace
+                offset = defaultHtmlReplace(htmlText, &data, pos, QStringLiteral("tt"));
+                pos += offset -1;
+                linkOffset += offset -1;
+                break;
             case '\x03': //color
                 {
                     QString fgColor, bgColor;
@@ -1806,6 +1811,10 @@ QString IRCView::removeDuplicateCodes(const QString& codes, TextHtmlData* data,
                 defaultRemoveDuplicateHandling(data, QStringLiteral("s"));
                 ++pos;
                 break;
+            case '\x11': //monospace
+                defaultRemoveDuplicateHandling(data, QStringLiteral("tt"));
+                ++pos;
+                break;
             case '\x0f': //reset to default
                 data->openHtmlTags.clear();
                 data->lastBgColor.clear();
@@ -1925,7 +1934,6 @@ void IRCView::adjustUrlRanges(QList< QPair<int, int> >& urlRanges, const QString
 {
     Q_UNUSED(fixedUrls)
 
-    QRegExp ircRichtextRegExp(colorRegExp);
     int start = 0, j;
     int i = 0;
     QString url;
@@ -1952,14 +1960,18 @@ void IRCView::adjustUrlRanges(QList< QPair<int, int> >& urlRanges, const QString
                     break;
                 }
             }
-            else if (ircRichtextRegExp.exactMatch(richtext.at(i)))
-            {
-                ircRichtextRegExp.indexIn(richtext, i);
-                i += ircRichtextRegExp.matchedLength() - 1;
-            }
             else
             {
-                j = 0;
+                QRegularExpressionMatch match = colorRegExp.match(richtext, i, QRegularExpression::NormalMatch, QRegularExpression::AnchoredMatchOption);
+                if (match.hasMatch())
+                {
+                    // forward to the last matched position
+                    i += match.capturedLength() - 1;
+                }
+                else
+                {
+                    j = 0;
+                }
             }
         }
     }
@@ -2099,7 +2111,7 @@ void IRCView::mouseReleaseEvent(QMouseEvent *ev)
     {
         m_mousePressedOnUrl = false;
     }
-    else if (ev->button() == Qt::MidButton)
+    else if (ev->button() == Qt::MiddleButton)
     {
         if (m_contextMenuOptions.testFlag(IrcContextMenus::ShowLinkActions))
         {
@@ -2376,18 +2388,10 @@ QDebug operator<<(QDebug d, QTextFrame* feed)
     if (feed)
     {
         d  << "\nDumping frame...";
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
         dN << Qt::hex << (void*)feed << Qt::dec;
-#else
-        dN << hex << (void*)feed << dec;
-#endif
         QTextFrame::iterator it = feed->begin();
         if (it.currentFrame() == feed)
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
             dS << "loop!" << Qt::endl;
-#else
-            dS << "loop!" << endl;
-#endif
         dS << "position" << feed->firstPosition() << feed->lastPosition();
         dN << "parentFrame=" << (void*)feed->parentFrame();
         dS;
@@ -2400,11 +2404,7 @@ QDebug operator<<(QDebug d, QTextFrame* feed)
                 //d<<"dumping blocks:";
                 QTextBlock b = it.currentBlock();
                 //d << "block" << b.position() << b.length();
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
                 d << Qt::endl << b;
-#else
-                d << endl << b;
-#endif
             }
             else if (frame != feed)
             {
@@ -2435,17 +2435,9 @@ QDebug operator<<(QDebug d, const QTextBlock &b)
     d   << "blockNumber"    << b.blockNumber();
     d   << "position"       << b.position();
     d   << "length"         << b.length();
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
     dN  << "firstChar 0x"   << Qt::hex << b.document()->characterAt(b.position()).unicode() << Qt::dec;
-#else
-    dN  << "firstChar 0x"   << hex << b.document()->characterAt(b.position()).unicode() << dec;
-#endif
     if (b.length() == 2)
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
         dN << " second 0x"   << Qt::hex << b.document()->characterAt(b.position()+1).unicode() << Qt::dec;
-#else
-        dN << " second 0x"   << hex << b.document()->characterAt(b.position()+1).unicode() << dec;
-#endif
     dS  << "userState"      << b.userState();
     dN  << "userData "      << (void*)b.userData();
     //dS  << "text"           << b.text();
